Package 'EstHTSeed'

Title: Hydro Time Analysis of Seed Germination
Description: Dry seed germinates by imbibing water from soil where the physiological process of germination starts after sufficient water has been imbibed by the seed. The germination time of the seed is inversely proportion to the difference between soil water potential and the base seed water potential which is described by hydro time model (Bradford, 2002 <https://www.jstor.org/stable/4046371>). The parameters of the model like speed of germination, stress tolerance, uniformity of germination are unknown fixed values (Ghosh et al., 2026 <doi:10.1111/aab.70041>) which are to be estimated using statistical regression model where the validity of the adopted statistical model has been established theoretically. The package will help to estimate the tuning parameter for proportion of viable seeds along with standard error and p- values for inference.
Authors: Dr. Himadri Ghosh [aut, cre], Dr. Debopam Rakshit [aut], Dr. Md Yeasin [aut], Mr. Saikath Das [aut]
Maintainer: Dr. Himadri Ghosh <[email protected]>
License: GPL-3
Version: 0.1.0
Built: 2026-06-08 08:35:37 UTC
Source: https://github.com/cran/EstHTSeed

Help Index


Estimation of Hydro Time Parameters of Seed Germination

Description

This function provides the estimates of hydro time constant (Theta), stress tolerance parameter (Mu), and uniformity parameter (Sigma) based on logit, probit and complementary log-log models fitted to observed cumulated number of germinated seeds.

Usage

EstHTSeed(model, psi, time, c.germinated, d_values, N, H0_Theta, H0_Mu, H0_Sigma)

Arguments

model

Model to be fitted

psi

Soil water potential

time

Time required for germination

c.germinated

Cumulated number of germinated seeds

d_values

Number of viable seeds under each psi, see example for input format

N

Total number of seeds under each psi, see example for input format

H0_Theta

Null hypothesis of hydro time constant, default 0

H0_Mu

Null hypothesis of stress tolerance parameter, default 0

H0_Sigma

Null hypothesis of uniformity parameter, default 0

Value

  • Message: Minimum of maximum cumulative fraction of seed germination

  • Estimated Parameters: The estimated values of Theta, Mu, and Sigma along with their testing of significance based on provided null hypothesis

  • MSE: Mean Square Error of fitted model under each psi

  • PLOT: Plot of observed and theoretical cumulative germination fraction under each psi

References

  • Bradford, K. J. (2002). Applications of Hydrothermal Time to Quantifying and Modeling Seed Germination and Dormancy. Weed Science, 50(2), 248–260. http://www.jstor.org/stable/4046371

  • Ghosh, H., Kumari, S., Das, S., Rakshit, D., Barman, S., Yeasin, M., ... & Kumar, S. (2026). Development of statistical models for analysis of seed germination behaviour of rice (Oryza sativa L.) under differential temperature and water potential. Annals of Applied Biology, 188(1), 195-220. doi:10.1111/aab.70041

Examples

d <- '0:0.80, -0.2:0.80, -0.4:0.60'
N <- '0:100, -0.2:100, -0.4:100'
psi <- c(rep(0, times = 19), rep(-0.2, times = 6), rep(-0.4, times = 10))
time <- c(1.5,2,2.5,3,3.5,4,4.5,5,6,7,9,10,12,16,18,20,23,26,30,4.5,5,6,20,
23,30,3,3.5,4,4.5,5,6,7,9,12,16)
c.germinated <- c(1,2,6,11,20,24,30,34,39,41,43,47,56,58,59,63,67,72,73,29,
31,35,63,64,65,11,13,18,21,22,25,26,28,29,30)
m1 <- EstHTSeed(model = 'Logit', psi= psi, time = time, c.germinated = c.germinated,
d_values = d, N = N)# Using logit model
m2 <- EstHTSeed(model = 'Probit', psi= psi, time = time, c.germinated = c.germinated,
d_values = d, N = N)# Using probit model
m3 <- EstHTSeed(model = 'Complementary log-log', psi= psi, time = time, c.germinated
= c.germinated, d_values = d, N = N) # Using complementary log-log model